<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
  <context>
    <name>CmdApproxCylinder</name>
    <message>
      <location filename="../../Command.cpp" line="205"/>
      <source>Reverse Engineering</source>
      <translation>Rétro-ingénierie</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="206"/>
      <source>Cylinder</source>
      <translation>Cylindre</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="207"/>
      <source>Approximate a cylinder</source>
      <translation>Approximer un cylindre</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="104"/>
      <source>Reverse Engineering</source>
      <translation>Rétro-ingénierie</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Plane...</source>
      <translation>Planifier...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Approximate a plane</source>
      <translation>Approximer un plan</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxPolynomial</name>
    <message>
      <location filename="../../Command.cpp" line="318"/>
      <source>Reverse Engineering</source>
      <translation>Rétro-ingénierie</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="319"/>
      <source>Polynomial surface</source>
      <translation>Surface polynomiale</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="320"/>
      <source>Approximate a polynomial surface</source>
      <translation>Approximer une surface polynomiale</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSphere</name>
    <message>
      <location filename="../../Command.cpp" line="271"/>
      <source>Reverse Engineering</source>
      <translation>Rétro-ingénierie</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="272"/>
      <source>Sphere</source>
      <translation>Sphère</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="273"/>
      <source>Approximate a sphere</source>
      <translation>Approximer une sphère</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="68"/>
      <source>Reverse Engineering</source>
      <translation>Rétro-ingénierie</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="69"/>
      <source>Approximate B-spline surface...</source>
      <translation>Approximer la surface de la B-spline...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="70"/>
      <source>Approximate a B-spline surface</source>
      <translation>Approximer la surface d’une B-spline</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshBoundary</name>
    <message>
      <location filename="../../Command.cpp" line="484"/>
      <source>Reverse Engineering</source>
      <translation>Rétro-ingénierie</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="485"/>
      <source>Wire from mesh boundary...</source>
      <translation>Fil à partir de la limite du maillage...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="486"/>
      <source>Create wire from mesh boundaries</source>
      <translation>Créer un fil à partir des limites du maillage</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location filename="../../Command.cpp" line="550"/>
      <source>Reverse Engineering</source>
      <translation>Rétro-ingénierie</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="551"/>
      <source>Poisson...</source>
      <translation>Poisson...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="552"/>
      <source>Poisson surface reconstruction</source>
      <translation>Reconstruction de surface Poisson</translation>
    </message>
  </context>
  <context>
    <name>CmdSegmentation</name>
    <message>
      <location filename="../../Command.cpp" line="373"/>
      <source>Reverse Engineering</source>
      <translation>Rétro-ingénierie</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="374"/>
      <source>Mesh segmentation...</source>
      <translation>Segmentation du maillage...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="375"/>
      <source>Create mesh segments</source>
      <translation>Segmenter le maillage</translation>
    </message>
  </context>
  <context>
    <name>CmdSegmentationFromComponents</name>
    <message>
      <location filename="../../Command.cpp" line="434"/>
      <source>Reverse Engineering</source>
      <translation>Rétro-ingénierie</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="435"/>
      <source>From components</source>
      <translation>Depuis les composants</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="436"/>
      <source>Create mesh segments from components</source>
      <translation>Créer des segments de maillage à partir des composants</translation>
    </message>
  </context>
  <context>
    <name>CmdSegmentationManual</name>
    <message>
      <location filename="../../Command.cpp" line="405"/>
      <source>Reverse Engineering</source>
      <translation>Rétro-ingénierie</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="406"/>
      <source>Manual segmentation...</source>
      <translation>Segmentation manuelle...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="407"/>
      <source>Create mesh segments manually</source>
      <translation>Créer des segments de maillage manuellement</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location filename="../../Command.cpp" line="584"/>
      <source>Reverse Engineering</source>
      <translation>Rétro-ingénierie</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="585"/>
      <source>Structured point clouds</source>
      <translation>Nuages structurés de points</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="586"/>
      <location filename="../../Command.cpp" line="587"/>
      <source>Triangulation of structured point clouds</source>
      <translation>Triangulation des nuages structurés de points</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="184"/>
      <source>Fit plane</source>
      <translation>Ajuster le plan</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="215"/>
      <source>Fit cylinder</source>
      <translation>Ajuster le cylindre</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="281"/>
      <source>Fit sphere</source>
      <translation>Ajuster la sphère</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="329"/>
      <source>Fit polynomial surface</source>
      <translation>Ajuster la surface polynomiale</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="595"/>
      <source>View triangulation</source>
      <translation>Afficher la triangulation</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="150"/>
      <source>Placement</source>
      <translation>Placement</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="222"/>
      <source>Fit B-Spline</source>
      <translation>Ajuster la B-spline</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="91"/>
      <source>Poisson reconstruction</source>
      <translation>Reconstruction de Poisson</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.cpp" line="257"/>
      <source>Segmentation</source>
      <translation>Segmentation</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="14"/>
      <source>Fit B-spline surface</source>
      <translation>Ajuster la surface de la B-spline</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="20"/>
      <source>u-Direction</source>
      <translation>direction u</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="26"/>
      <location filename="../../FitBSplineSurface.ui" line="93"/>
      <source>Degree</source>
      <translation>Degré</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="55"/>
      <location filename="../../FitBSplineSurface.ui" line="122"/>
      <source>Control points</source>
      <translation>Points de controle</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="87"/>
      <source>v-Direction</source>
      <translation>direction v</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="154"/>
      <source>Settings</source>
      <translation>Réglages</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="160"/>
      <source>Iterations</source>
      <translation>Itérations</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="189"/>
      <source>Size factor</source>
      <translation>Facteur de taille</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="218"/>
      <source>User-defined u/v directions</source>
      <translation>Directions u/v personnalisés</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="231"/>
      <source>Create placement</source>
      <translation>Créer un placement</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="238"/>
      <source>Smoothing</source>
      <translation>Lissage</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="247"/>
      <source>Total Weight</source>
      <translation>Poids total</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="276"/>
      <source>Length of gradient</source>
      <translation>Longueur du dégradé</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="305"/>
      <source>Bending energy</source>
      <translation>Énergie de flexion</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="334"/>
      <source>Curvature variation</source>
      <translation>Variation de courbure</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="161"/>
      <location filename="../../FitBSplineSurface.cpp" line="229"/>
      <source>Input error</source>
      <translation>Erreur de saisie</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="201"/>
      <source>Wrong selection</source>
      <translation>Sélection invalide</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="202"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>Veuillez sélectionner l'emplacement d'un seul objet pour obtenir l'orientation locale.</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="14"/>
      <source>Poisson</source>
      <translation>Poisson</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="20"/>
      <source>Parameters</source>
      <translation>Paramètres</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="26"/>
      <source>Octree depth</source>
      <translation>Profondeur des Octree</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="46"/>
      <source>Solver divide</source>
      <translation>Divisions du solveur</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="66"/>
      <source>Samples per node</source>
      <translation>Samples par noeuds</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="98"/>
      <source>Input error</source>
      <translation>Erreur de saisie</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="83"/>
      <location filename="../../Command.cpp" line="563"/>
      <source>Wrong selection</source>
      <translation>Sélection invalide</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="84"/>
      <source>Please select a point cloud or mesh.</source>
      <translation>Veuillez sélectionner un nuage de points ou un maillage.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="564"/>
      <source>Please select a single point cloud.</source>
      <translation>Merci de sélectionner un point du nuage de points.</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location filename="../../Command.cpp" line="617"/>
      <source>View triangulation failed</source>
      <translation>Erreur de la vue en triangulation</translation>
    </message>
  </context>
  <context>
    <name>ReverseEngineeringGui::Segmentation</name>
    <message>
      <location filename="../../Segmentation.ui" line="14"/>
      <source>Mesh segmentation</source>
      <translation>Segmentation du maillage</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="20"/>
      <source>Smooth mesh</source>
      <translation>Lissage du maillage</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="37"/>
      <source>Plane</source>
      <translation>Plan</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="46"/>
      <source>Curvature tolerance</source>
      <translation>Tolérance de courbure</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="63"/>
      <source>Distance to plane</source>
      <translation>Distance au plan</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="80"/>
      <source>Minimum number of faces</source>
      <translation>Nombre minimum de faces</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="100"/>
      <source>Create mesh from unused triangles</source>
      <translation>Créer un maillage à partir de triangles inutilisés</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="107"/>
      <source>Create compound</source>
      <translation>Créer un composé</translation>
    </message>
  </context>
  <context>
    <name>ReverseEngineeringGui::SegmentationManual</name>
    <message>
      <location filename="../../SegmentationManual.ui" line="14"/>
      <source>Manual segmentation</source>
      <translation>Segmentation manuelle</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="20"/>
      <source>Select</source>
      <translation>Sélectionner</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="41"/>
      <source>Region</source>
      <translation>Région</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="61"/>
      <source>All</source>
      <translation>Tout</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="81"/>
      <source>Components</source>
      <translation>Composants</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="88"/>
      <source>&lt; faces than</source>
      <translation>des faces &lt; à</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="98"/>
      <source>Pick triangle</source>
      <translation>Choisir un triangle</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="105"/>
      <source>Select whole component</source>
      <translation>Sélectionner le composant entier</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="112"/>
      <source>Clear</source>
      <translation>Effacer</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="122"/>
      <source>Plane</source>
      <translation>Plan</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="128"/>
      <location filename="../../SegmentationManual.ui" line="181"/>
      <location filename="../../SegmentationManual.ui" line="234"/>
      <source>Detect</source>
      <translation>Détecter</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="135"/>
      <location filename="../../SegmentationManual.ui" line="188"/>
      <location filename="../../SegmentationManual.ui" line="241"/>
      <source>Tolerance</source>
      <translation>Tolérance</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="155"/>
      <location filename="../../SegmentationManual.ui" line="208"/>
      <location filename="../../SegmentationManual.ui" line="261"/>
      <source>Minimum number of faces</source>
      <translation>Nombre minimum de faces</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="175"/>
      <source>Cylinder</source>
      <translation>Cylindre</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="228"/>
      <source>Sphere</source>
      <translation>Sphère</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="281"/>
      <source>Region options</source>
      <translation>Options de région</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="287"/>
      <source>Respect only visible triangles</source>
      <translation>Respecter uniquement les triangles visibles</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="297"/>
      <source>Respect only triangles with normals facing screen</source>
      <translation>Respecter seulement les triangles dont les normales font face à écran</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="310"/>
      <source>Segmentation</source>
      <translation>Segmentation</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="316"/>
      <source>Cut segment from mesh</source>
      <translation>Couper le segment du maillage</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="326"/>
      <source>Hide segment</source>
      <translation>Cacher un segment</translation>
    </message>
  </context>
  <context>
    <name>ReverseEngineeringGui::TaskSegmentationManual</name>
    <message>
      <location filename="../../SegmentationManual.cpp" line="333"/>
      <source>Create</source>
      <translation>Créer</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="34"/>
      <source>Reverse Engineering</source>
      <translation>Rétro-ingénierie</translation>
    </message>
  </context>
</TS>
